# acmenra_cv/render/style/enums.py

import logging
from enum import Enum


logger = logging.getLogger(__name__)


class LabelPosition(Enum):
    """
    Enumeration for label/badge positioning on rendered frames.

    Defines where information pills (ID, class, confidence) should be attached
    relative to the bounding geometry.
    """
    LEFT = "left"
    RIGHT = "right"
    TOP = "top"
    BOTTOM = "bottom"
    CENTER = "center"
    OFF = "off"