# acmenra_cv/render/style/__init__.py

import logging

from acmenra_cv.render.style.font import Font
from acmenra_cv.render.style.fill import Fill
from acmenra_cv.render.style.style import Style
from acmenra_cv.render.style.stroke import Stroke
from acmenra_cv.render.style.enums import LabelPosition


logger = logging.getLogger(__name__)


__all__ = [
    'Font',
    'Fill',
    'Style',
    'Stroke',
    'LabelPosition'
]


__version__ = "0.1.7.10"