# acmenra_cv/__init__.py

import logging

from acmenra_cv.inference import Timing, Result
from acmenra_cv.render import Drawer, Font, Fill, Style, Stroke, LabelPosition
from acmenra_cv.instance import Point, Box, Obb, Polygon, Instance, TaskType, DeviceType
from acmenra_cv.tracker import TimedPoint, TimedPointQueue, TrackedObject, Tracker
from acmenra_cv.utils import get_frame_illumination, IlluminationMethod, IlluminationCurveType, LightingCondition


logger = logging.getLogger(__name__)


__all__ = [
    'Point',
    'Box',
    'Obb',
    'Polygon',
    'Instance',
    'TaskType',
    'DeviceType',
    'Result',
    'Timing',
    'Drawer',
    'Font',
    'Fill',
    'Style',
    'Stroke',
    'LabelPosition',
    'Tracker',
    'TimedPoint',
    'TrackedObject',
    'TimedPointQueue',
    'get_frame_illumination',
    'IlluminationMethod',
    'IlluminationCurveType',
    'LightingCondition',
]


__version__ = "0.1.7.10"