# acmenra_cv/inference/__init__.py

import logging

from acmenra_cv.inference.result import Result
from acmenra_cv.inference.timing import Timing


logger = logging.getLogger(__name__)


__all__ = [
    'Result',
    'Timing',
]


__version__ = "0.1.7.10"